summaryrefslogtreecommitdiffstats
path: root/kaddressbook
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
commitfd5d099065a748cac49e20a13481f85666c53c71 (patch)
treea0f1672cd88eb0e69b9ddc2ed9b08ecd98538bd3 /kaddressbook
parentb440a9c608596cd88efdb3bfa4661c5e37efbe4b (diff)
downloadtdepim-fd5d099065a748cac49e20a13481f85666c53c71.tar.gz
tdepim-fd5d099065a748cac49e20a13481f85666c53c71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kaddressbook')
-rw-r--r--kaddressbook/addresseditwidget.cpp2
-rw-r--r--kaddressbook/addresseditwidget.h2
-rw-r--r--kaddressbook/addresseeeditorwidget.cpp2
-rw-r--r--kaddressbook/customfieldswidget.cpp2
-rw-r--r--kaddressbook/distributionlistpicker.cpp2
-rw-r--r--kaddressbook/distributionlistpicker.h4
-rw-r--r--kaddressbook/editors/imeditorbase.ui2
-rw-r--r--kaddressbook/editors/imeditorwidget.cpp6
-rw-r--r--kaddressbook/editors/imeditorwidget.h4
-rw-r--r--kaddressbook/emaileditwidget.cpp2
-rw-r--r--kaddressbook/emaileditwidget.h2
-rw-r--r--kaddressbook/extensionmanager.cpp8
-rw-r--r--kaddressbook/extensionmanager.h8
-rw-r--r--kaddressbook/features/distributionlistngwidget.cpp6
-rw-r--r--kaddressbook/features/distributionlistngwidget.h2
-rw-r--r--kaddressbook/features/distributionlistwidget.cpp4
-rw-r--r--kaddressbook/features/distributionlistwidget.h2
-rw-r--r--kaddressbook/features/resourceselection.cpp4
-rw-r--r--kaddressbook/features/resourceselection.h2
-rw-r--r--kaddressbook/filtereditdialog.cpp4
-rw-r--r--kaddressbook/filtereditdialog.h8
-rw-r--r--kaddressbook/geowidget.cpp2
-rw-r--r--kaddressbook/imeditwidget.h2
-rw-r--r--kaddressbook/interfaces/core.h6
-rw-r--r--kaddressbook/interfaces/xxport.cpp4
-rw-r--r--kaddressbook/kabcore.cpp42
-rw-r--r--kaddressbook/kabcore.h44
-rw-r--r--kaddressbook/kaddressbookmain.cpp4
-rw-r--r--kaddressbook/kaddressbookmain.h2
-rw-r--r--kaddressbook/kaddressbookview.h4
-rw-r--r--kaddressbook/kcmconfigs/addhostdialog.cpp2
-rw-r--r--kaddressbook/kcmconfigs/kabconfigwidget.h2
-rw-r--r--kaddressbook/kcmconfigs/ldapoptionswidget.cpp2
-rw-r--r--kaddressbook/kcmconfigs/ldapoptionswidget.h4
-rw-r--r--kaddressbook/main.cpp6
-rw-r--r--kaddressbook/nameeditdialog.cpp2
-rw-r--r--kaddressbook/printing/ds_appearance.ui10
-rw-r--r--kaddressbook/viewmanager.cpp14
-rw-r--r--kaddressbook/viewmanager.h8
-rw-r--r--kaddressbook/views/colorlistbox.cpp2
-rw-r--r--kaddressbook/views/colorlistbox.h2
-rw-r--r--kaddressbook/views/configurecardviewdialog.cpp4
-rw-r--r--kaddressbook/views/contactlistview.cpp14
-rw-r--r--kaddressbook/views/contactlistview.h4
-rw-r--r--kaddressbook/views/kaddressbooktableview.cpp6
-rw-r--r--kaddressbook/views/kaddressbooktableview.h4
46 files changed, 137 insertions, 137 deletions
diff --git a/kaddressbook/addresseditwidget.cpp b/kaddressbook/addresseditwidget.cpp
index 5d17f4ef..bb4938b8 100644
--- a/kaddressbook/addresseditwidget.cpp
+++ b/kaddressbook/addresseditwidget.cpp
@@ -358,7 +358,7 @@ AddressEditDialog::AddressEditDialog( const KABC::Address::List &list,
connect( mCountryCombo, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( modified() ) );
connect( mPreferredCheckBox, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( modified() ) );
- KAcceleratorManager::manage( this );
+ TDEAcceleratorManager::manage( this );
mChanged = false;
diff --git a/kaddressbook/addresseditwidget.h b/kaddressbook/addresseditwidget.h
index c6d5e858..c5b2f597 100644
--- a/kaddressbook/addresseditwidget.h
+++ b/kaddressbook/addresseditwidget.h
@@ -42,7 +42,7 @@ class TQToolButton;
class KActiveLabel;
class KComboBox;
class KLineEdit;
-class KListView;
+class TDEListView;
typedef TypeCombo<KABC::Address> AddressTypeCombo;
diff --git a/kaddressbook/addresseeeditorwidget.cpp b/kaddressbook/addresseeeditorwidget.cpp
index c1173b37..a53d6c34 100644
--- a/kaddressbook/addresseeeditorwidget.cpp
+++ b/kaddressbook/addresseeeditorwidget.cpp
@@ -847,7 +847,7 @@ void AddresseeEditorWidget::invalidDate()
void AddresseeEditorWidget::pageChanged( TQWidget *wdg )
{
if ( wdg )
- KAcceleratorManager::manage( wdg );
+ TDEAcceleratorManager::manage( wdg );
}
void AddresseeEditorWidget::setInitialFocus()
diff --git a/kaddressbook/customfieldswidget.cpp b/kaddressbook/customfieldswidget.cpp
index 3212e8c0..13536148 100644
--- a/kaddressbook/customfieldswidget.cpp
+++ b/kaddressbook/customfieldswidget.cpp
@@ -72,7 +72,7 @@ AddFieldDialog::AddFieldDialog( TQWidget *parent, const char *name )
connect( mTitle, TQT_SIGNAL( textChanged( const TQString& ) ),
this, TQT_SLOT( nameChanged( const TQString& ) ) );
- KAcceleratorManager::manage( this );
+ TDEAcceleratorManager::manage( this );
mTypeList.append( "text" );
mTypeName.append( i18n( "Text" ) );
diff --git a/kaddressbook/distributionlistpicker.cpp b/kaddressbook/distributionlistpicker.cpp
index d3aef15e..354a24a2 100644
--- a/kaddressbook/distributionlistpicker.cpp
+++ b/kaddressbook/distributionlistpicker.cpp
@@ -52,7 +52,7 @@ KPIM::DistributionListPickerDialog::DistributionListPickerDialog( KABC::AddressB
layout->setSpacing( KDialog::spacingHint() );
m_label = new TQLabel( main );
layout->addWidget( m_label, 0, 0 );
- m_listBox = new KListBox( main );
+ m_listBox = new TDEListBox( main );
layout->addWidget( m_listBox, 1, 0 );
connect( m_listBox, TQT_SIGNAL( highlighted( const TQString& ) ),
this, TQT_SLOT( entrySelected( const TQString& ) ) );
diff --git a/kaddressbook/distributionlistpicker.h b/kaddressbook/distributionlistpicker.h
index c101a3a4..d38f936d 100644
--- a/kaddressbook/distributionlistpicker.h
+++ b/kaddressbook/distributionlistpicker.h
@@ -27,7 +27,7 @@
#include <tqstring.h>
-class KListBox;
+class TDEListBox;
namespace KABC {
class AddressBook;
@@ -61,7 +61,7 @@ private slots:
private:
KABC::AddressBook* m_book;
TQLabel* m_label;
- KListBox* m_listBox;
+ TDEListBox* m_listBox;
TQString m_selectedDistributionList;
};
diff --git a/kaddressbook/editors/imeditorbase.ui b/kaddressbook/editors/imeditorbase.ui
index 40270b50..de9fff55 100644
--- a/kaddressbook/editors/imeditorbase.ui
+++ b/kaddressbook/editors/imeditorbase.ui
@@ -82,7 +82,7 @@
<string>&amp;Add...</string>
</property>
</widget>
- <widget class="KListView" row="0" column="0" rowspan="5" colspan="1">
+ <widget class="TDEListView" row="0" column="0" rowspan="5" colspan="1">
<column>
<property name="text">
<string>Protocol</string>
diff --git a/kaddressbook/editors/imeditorwidget.cpp b/kaddressbook/editors/imeditorwidget.cpp
index c8047d90..45523de5 100644
--- a/kaddressbook/editors/imeditorwidget.cpp
+++ b/kaddressbook/editors/imeditorwidget.cpp
@@ -43,9 +43,9 @@
#include "imeditorwidget.h"
-IMAddressLVI::IMAddressLVI( KListView *parent, KPluginInfo *protocol,
+IMAddressLVI::IMAddressLVI( TDEListView *parent, KPluginInfo *protocol,
const TQString &address, const IMContext &context )
- : KListViewItem( parent )
+ : TDEListViewItem( parent )
{
setProtocol( protocol );
setAddress( address );
@@ -72,7 +72,7 @@ void IMAddressLVI::paintCell( TQPainter *p, const TQColorGroup &cg,
p->setFont( font );
}
- KListViewItem::paintCell( p, cg, column, width, alignment );
+ TDEListViewItem::paintCell( p, cg, column, width, alignment );
}
void IMAddressLVI::setAddress( const TQString &address )
diff --git a/kaddressbook/editors/imeditorwidget.h b/kaddressbook/editors/imeditorwidget.h
index cca9b064..62fb36df 100644
--- a/kaddressbook/editors/imeditorwidget.h
+++ b/kaddressbook/editors/imeditorwidget.h
@@ -97,10 +97,10 @@ class IMEditorWidget : public KDialogBase
*/
// VCard has been disabled as there is no standard VCard location to store IM addresses yet.
-class IMAddressLVI : public KListViewItem
+class IMAddressLVI : public TDEListViewItem
{
public:
- IMAddressLVI( KListView *parent, KPluginInfo * protocol,
+ IMAddressLVI( TDEListView *parent, KPluginInfo * protocol,
const TQString &address, const IMContext &context = Any );
void setAddress( const TQString &address );
diff --git a/kaddressbook/emaileditwidget.cpp b/kaddressbook/emaileditwidget.cpp
index a04a88a9..7b5fe4c9 100644
--- a/kaddressbook/emaileditwidget.cpp
+++ b/kaddressbook/emaileditwidget.cpp
@@ -224,7 +224,7 @@ EmailEditDialog::EmailEditDialog( const TQStringList &list, TQWidget *parent,
// set default state
selectionChanged( -1 );
- KAcceleratorManager::manage( this );
+ TDEAcceleratorManager::manage( this );
setInitialSize( TQSize( 400, 200 ) );
}
diff --git a/kaddressbook/emaileditwidget.h b/kaddressbook/emaileditwidget.h
index c818ed38..f584023c 100644
--- a/kaddressbook/emaileditwidget.h
+++ b/kaddressbook/emaileditwidget.h
@@ -35,7 +35,7 @@ class TQToolButton;
class KComboBox;
class KLineEdit;
-class KListView;
+class TDEListView;
/**
This widget displays a list box of the email addresses as well as buttons
diff --git a/kaddressbook/extensionmanager.cpp b/kaddressbook/extensionmanager.cpp
index bd565a84..c184adf0 100644
--- a/kaddressbook/extensionmanager.cpp
+++ b/kaddressbook/extensionmanager.cpp
@@ -57,7 +57,7 @@ ExtensionManager::ExtensionManager( TQWidget* extensionBar, TQWidgetStack* detai
createExtensionWidgets();
- mActionCollection = new KActionCollection( this, "ActionCollection" );
+ mActionCollection = new TDEActionCollection( this, "ActionCollection" );
extensionBar->setShown( false );
TQTimer::singleShot( 0, this, TQT_SLOT( createActions() ) );
@@ -75,7 +75,7 @@ void ExtensionManager::restoreSettings()
typedef TQMap<TQString, ExtensionData>::ConstIterator ConstIterator;
for ( ConstIterator it = mExtensionMap.begin(), end = mExtensionMap.end(); it != end; ++it ) {
if ( activeExtensions.contains( it.data().identifier ) ) {
- KToggleAction *action = static_cast<KToggleAction*>( it.data().action );
+ TDEToggleAction *action = static_cast<TDEToggleAction*>( it.data().action );
if ( action )
action->setChecked( true );
setExtensionActive( it.data().identifier, true );
@@ -168,7 +168,7 @@ void ExtensionManager::createActions()
ExtensionData::List::ConstIterator it;
for ( TQMap<TQString, ExtensionData>::Iterator it = mExtensionMap.begin(), end = mExtensionMap.end(); it != end; ++it ) {
ExtensionData& data = it.data();
- data.action = new KToggleAction( data.title, 0, mMapper, TQT_SLOT( map() ),
+ data.action = new TDEToggleAction( data.title, 0, mMapper, TQT_SLOT( map() ),
mActionCollection,
TQString( data.identifier + "_extension" ).latin1() );
mMapper->setMapping( data.action, data.identifier );
@@ -178,7 +178,7 @@ void ExtensionManager::createActions()
data.action->setChecked( true );
}
- mActionList.append( new KActionSeparator( mActionCollection ) );
+ mActionList.append( new TDEActionSeparator( mActionCollection ) );
mCore->guiClient()->plugActionList( "extensions_list", mActionList );
}
diff --git a/kaddressbook/extensionmanager.h b/kaddressbook/extensionmanager.h
index ff2ce1a2..b80ec01c 100644
--- a/kaddressbook/extensionmanager.h
+++ b/kaddressbook/extensionmanager.h
@@ -33,7 +33,7 @@
class TQSignalMapper;
class TQWidgetStack;
-class KActionCollection;
+class TDEActionCollection;
namespace KAB {
class Core;
@@ -45,7 +45,7 @@ class ExtensionData
ExtensionData();
typedef TQValueList<ExtensionData> List;
- KToggleAction* action;
+ TDEToggleAction* action;
KAB::ExtensionWidget *widget;
TQString identifier;
TQString title;
@@ -109,8 +109,8 @@ class ExtensionManager : public TQObject
TQMap<TQString, ExtensionData> mExtensionMap;
TQStringList mActiveExtensions;
TQSignalMapper *mMapper;
- TQPtrList<KAction> mActionList;
- KActionCollection *mActionCollection;
+ TQPtrList<TDEAction> mActionList;
+ TDEActionCollection *mActionCollection;
TQSplitter *mSplitter;
TQWidgetStack *mDetailsStack;
TQWidget *mActiveDetailsWidget;
diff --git a/kaddressbook/features/distributionlistngwidget.cpp b/kaddressbook/features/distributionlistngwidget.cpp
index f91142e8..6dda79de 100644
--- a/kaddressbook/features/distributionlistngwidget.cpp
+++ b/kaddressbook/features/distributionlistngwidget.cpp
@@ -44,7 +44,7 @@
#include <tqpushbutton.h>
#include <tqtooltip.h>
-KAB::DistributionListNg::ListBox::ListBox( TQWidget* parent ) : KListBox( parent )
+KAB::DistributionListNg::ListBox::ListBox( TQWidget* parent ) : TDEListBox( parent )
{
setAcceptDrops( true );
}
@@ -62,7 +62,7 @@ void KAB::DistributionListNg::ListBox::dragMoveEvent( TQDragMoveEvent *event )
void KAB::DistributionListNg::ListBox::dragEnterEvent( TQDragEnterEvent *event )
{
- KListBox::dragEnterEvent( event );
+ TDEListBox::dragEnterEvent( event );
}
void KAB::DistributionListNg::ListBox::dropEvent( TQDropEvent *event )
@@ -170,7 +170,7 @@ KAB::DistributionListNg::MainWidget::MainWidget( KAB::Core *core, TQWidget *pare
void KAB::DistributionListNg::MainWidget::contextMenuRequested( TQListBoxItem *item, const TQPoint &point )
{
- TQGuardedPtr<KPopupMenu> menu = new KPopupMenu( this );
+ TQGuardedPtr<TDEPopupMenu> menu = new TDEPopupMenu( this );
menu->insertItem( i18n( "New Distribution List..." ), core(), TQT_SLOT( newDistributionList() ) );
if ( item && ( item->text() !=i18n( "All Contacts" ) ) )
{
diff --git a/kaddressbook/features/distributionlistngwidget.h b/kaddressbook/features/distributionlistngwidget.h
index 1121af45..dc4b036d 100644
--- a/kaddressbook/features/distributionlistngwidget.h
+++ b/kaddressbook/features/distributionlistngwidget.h
@@ -44,7 +44,7 @@ namespace KABC {
namespace KAB {
namespace DistributionListNg {
-class ListBox : public KListBox
+class ListBox : public TDEListBox
{
Q_OBJECT
diff --git a/kaddressbook/features/distributionlistwidget.cpp b/kaddressbook/features/distributionlistwidget.cpp
index f48b5e96..e77e3fc3 100644
--- a/kaddressbook/features/distributionlistwidget.cpp
+++ b/kaddressbook/features/distributionlistwidget.cpp
@@ -223,7 +223,7 @@ DistributionListWidget::DistributionListWidget( KAB::Core *core, TQWidget *paren
mContactView->restoreLayout( TDEGlobal::config(), "DistributionListViewColumns" );
- KAcceleratorManager::manage( this );
+ TDEAcceleratorManager::manage( this );
}
DistributionListWidget::~DistributionListWidget()
@@ -591,7 +591,7 @@ void DistributionListWidget::changed()
#endif
DistributionListView::DistributionListView( TQWidget *parent, const char* name )
- : KListView( parent, name )
+ : TDEListView( parent, name )
{
setDragEnabled( true );
setAcceptDrops( true );
diff --git a/kaddressbook/features/distributionlistwidget.h b/kaddressbook/features/distributionlistwidget.h
index 5d0a5097..59a5d88b 100644
--- a/kaddressbook/features/distributionlistwidget.h
+++ b/kaddressbook/features/distributionlistwidget.h
@@ -105,7 +105,7 @@ class DistributionListWidget : public KAB::ExtensionWidget
/**
@short Helper class
*/
-class DistributionListView : public KListView
+class DistributionListView : public TDEListView
{
Q_OBJECT
diff --git a/kaddressbook/features/resourceselection.cpp b/kaddressbook/features/resourceselection.cpp
index 82d81de4..3534bcdb 100644
--- a/kaddressbook/features/resourceselection.cpp
+++ b/kaddressbook/features/resourceselection.cpp
@@ -57,7 +57,7 @@ class AddressBookWrapper : public KABC::AddressBook
class ResourceItem : public TQCheckListItem
{
public:
- ResourceItem( KListView *parent, KABC::Resource *resource )
+ ResourceItem( TDEListView *parent, KABC::Resource *resource )
: TQCheckListItem( parent, resource->resourceName(), CheckBox ),
mResource( resource ), mChecked( false ),
mIsSubresource( false ), mSubItemsCreated( false ),
@@ -510,7 +510,7 @@ void ResourceSelection::initGUI()
TQToolTip::add( mRemoveButton, i18n( "Remove addressbook" ) );
buttonLayout->addWidget( mRemoveButton );
- mListView = new KListView( this );
+ mListView = new TDEListView( this );
mListView->header()->hide();
mListView->addColumn( i18n( "Address Books" ) );
mListView->setFullWidth( true );
diff --git a/kaddressbook/features/resourceselection.h b/kaddressbook/features/resourceselection.h
index 4d2f513e..c986c5fc 100644
--- a/kaddressbook/features/resourceselection.h
+++ b/kaddressbook/features/resourceselection.h
@@ -80,7 +80,7 @@ class ResourceSelection : public KAB::ExtensionWidget
ResourceItem* selectedItem() const;
ResourceItem* findSubResourceItem( KPIM::ResourceABC *resource, const TQString &subResource );
- KListView *mListView;
+ TDEListView *mListView;
TQPushButton *mAddButton;
TQPushButton *mEditButton;
TQPushButton *mRemoveButton;
diff --git a/kaddressbook/filtereditdialog.cpp b/kaddressbook/filtereditdialog.cpp
index b1c5df43..3b3e37df 100644
--- a/kaddressbook/filtereditdialog.cpp
+++ b/kaddressbook/filtereditdialog.cpp
@@ -127,7 +127,7 @@ void FilterEditDialog::initGUI()
connect( mNameEdit, TQT_SIGNAL( textChanged( const TQString& ) ),
TQT_SLOT( filterNameTextChanged( const TQString&) ) );
- mCategoriesView = new KListView( page );
+ mCategoriesView = new TDEListView( page );
mCategoriesView->addColumn( i18n( "Category" ) );
mCategoriesView->setFullWidth( true );
topLayout->addMultiCellWidget( mCategoriesView, 1, 1, 0, 1 );
@@ -258,7 +258,7 @@ void FilterDialog::initGUI()
TQGridLayout *topLayout = new TQGridLayout( page, 1, 2, 0, spacingHint() );
- mFilterListBox = new KListBox( page );
+ mFilterListBox = new TDEListBox( page );
topLayout->addWidget( mFilterListBox, 0, 0 );
connect( mFilterListBox, TQT_SIGNAL( selectionChanged( TQListBoxItem * ) ),
TQT_SLOT( selectionChanged( TQListBoxItem * ) ) );
diff --git a/kaddressbook/filtereditdialog.h b/kaddressbook/filtereditdialog.h
index 063c2d67..3e2c9acf 100644
--- a/kaddressbook/filtereditdialog.h
+++ b/kaddressbook/filtereditdialog.h
@@ -30,8 +30,8 @@ class TQToolButton;
class TQWidget;
class KLineEdit;
-class KListBox;
-class KListView;
+class TDEListBox;
+class TDEListView;
#include <kdialogbase.h>
@@ -62,7 +62,7 @@ class FilterDialog : public KDialogBase
Filter::List mFilterList;
Filter::List mInternalFilterList;
- KListBox *mFilterListBox;
+ TDEListBox *mFilterListBox;
TQPushButton *mAddButton;
TQPushButton *mEditButton;
TQPushButton *mRemoveButton;
@@ -89,7 +89,7 @@ class FilterEditDialog : public KDialogBase
Filter mFilter;
KLineEdit *mNameEdit;
- KListView *mCategoriesView;
+ TDEListView *mCategoriesView;
TQButtonGroup *mMatchRuleGroup;
TQPushButton *mEditButton;
TQPushButton *mRemoveButton;
diff --git a/kaddressbook/geowidget.cpp b/kaddressbook/geowidget.cpp
index 8a275125..55714b36 100644
--- a/kaddressbook/geowidget.cpp
+++ b/kaddressbook/geowidget.cpp
@@ -246,7 +246,7 @@ GeoDialog::GeoDialog( TQWidget *parent, const char *name )
connect( mLongDirection, TQT_SIGNAL( activated( int ) ),
TQT_SLOT( sexagesimalInputChanged() ) );
- KAcceleratorManager::manage( this );
+ TDEAcceleratorManager::manage( this );
}
GeoDialog::~GeoDialog()
diff --git a/kaddressbook/imeditwidget.h b/kaddressbook/imeditwidget.h
index a70ed062..52f1ec26 100644
--- a/kaddressbook/imeditwidget.h
+++ b/kaddressbook/imeditwidget.h
@@ -35,7 +35,7 @@ class TQToolButton;
class KComboBox;
class KLineEdit;
-class KListView;
+class TDEListView;
/**
This widget displays a list box of the instant messaging addresses as well as buttons
diff --git a/kaddressbook/interfaces/core.h b/kaddressbook/interfaces/core.h
index c291f208..3a5baba9 100644
--- a/kaddressbook/interfaces/core.h
+++ b/kaddressbook/interfaces/core.h
@@ -44,7 +44,7 @@ class Resource;
class TQWidget;
-class KActionCollection;
+class TDEActionCollection;
class TDEConfig;
class KURL;
@@ -71,10 +71,10 @@ class KDE_EXPORT Core : public TQObject
virtual TDEConfig *config() const = 0;
/**
- Returns a pointer to the global KActionCollection object. So
+ Returns a pointer to the global TDEActionCollection object. So
other classes can register their actions easily.
*/
- virtual KActionCollection *actionCollection() const = 0;
+ virtual TDEActionCollection *actionCollection() const = 0;
/**
Returns a pointer to the gui client.
diff --git a/kaddressbook/interfaces/xxport.cpp b/kaddressbook/interfaces/xxport.cpp
index 68b88312..a934bb97 100644
--- a/kaddressbook/interfaces/xxport.cpp
+++ b/kaddressbook/interfaces/xxport.cpp
@@ -77,7 +77,7 @@ KABC::AddresseeList XXPort::importContacts( const TQString& ) const
void XXPort::createImportAction( const TQString &label, const TQString &data )
{
TQString id = "file_import_" + identifier() + ( data.isEmpty() ? TQString( "" ) : "_" + data );
- KAction *action = new KAction( label, 0, d->mImportMapper, TQT_SLOT( map() ), actionCollection(), id.latin1() );
+ TDEAction *action = new TDEAction( label, 0, d->mImportMapper, TQT_SLOT( map() ), actionCollection(), id.latin1() );
d->mImportMapper->setMapping( action, ( data.isEmpty() ? TQString( "<empty>" ) : data ) );
@@ -87,7 +87,7 @@ void XXPort::createImportAction( const TQString &label, const TQString &data )
void XXPort::createExportAction( const TQString &label, const TQString &data )
{
TQString id = "file_export_" + identifier() + ( data.isEmpty() ? TQString( "" ) : "_" + data );
- KAction *action = new KAction( label, 0, d->mExportMapper, TQT_SLOT( map() ), actionCollection(), id.latin1() );
+ TDEAction *action = new TDEAction( label, 0, d->mExportMapper, TQT_SLOT( map() ), actionCollection(), id.latin1() );
d->mExportMapper->setMapping( action, ( data.isEmpty() ? TQString( "<empty>" ) : data ) );
diff --git a/kaddressbook/kabcore.cpp b/kaddressbook/kabcore.cpp
index f88be3c3..a6f8a20b 100644
--- a/kaddressbook/kabcore.cpp
+++ b/kaddressbook/kabcore.cpp
@@ -190,7 +190,7 @@ KABCore::KABCore( KXMLGUIClient *client, bool readWrite, TQWidget *parent,
setModified( false );
- KAcceleratorManager::manage( mWidget );
+ TDEAcceleratorManager::manage( mWidget );
mKIMProxy = ::KIMProxy::instance( kapp->dcopClient() );
}
@@ -255,7 +255,7 @@ TDEConfig *KABCore::config() const
return KABPrefs::instance()->config();
}
-KActionCollection *KABCore::actionCollection() const
+TDEActionCollection *KABCore::actionCollection() const
{
return guiClient()->actionCollection();
}
@@ -1195,7 +1195,7 @@ void KABCore::slotEditorDestroyed( const TQString &uid )
void KABCore::initGUI()
{
TQVBoxLayout *topLayout = new TQVBoxLayout( mWidget, 0, 0 );
- KToolBar* searchTB = new KToolBar( mWidget, "search toolbar");
+ TDEToolBar* searchTB = new TDEToolBar( mWidget, "search toolbar");
searchTB->boxLayout()->setSpacing( KDialog::spacingHint() );
mIncSearchWidget = new IncSearchWidget( searchTB, "kde toolbar widget");
searchTB->setStretchableWidget( mIncSearchWidget );
@@ -1314,10 +1314,10 @@ void KABCore::initActions()
connect( TQApplication::clipboard(), TQT_SIGNAL( dataChanged() ),
TQT_SLOT( clipboardDataChanged() ) );
- KAction *action;
+ TDEAction *action;
// file menu
- mActionMail = new KAction( i18n( "&Send Email to Contact..." ), "mail_send", 0,
+ mActionMail = new TDEAction( i18n( "&Send Email to Contact..." ), "mail_send", 0,
this, TQT_SLOT( sendMail() ), actionCollection(), "file_mail" );
action = KStdAction::print( this, TQT_SLOT( print() ), actionCollection() );
mActionMail->setWhatsThis( i18n( "Send a mail to all selected contacts." ) );
@@ -1327,30 +1327,30 @@ void KABCore::initActions()
TQT_SLOT( save() ), actionCollection(), "file_sync" );
mActionSave->setWhatsThis( i18n( "Save all changes of the address book to the storage backend." ) );
- action = new KAction( i18n( "&New Contact..." ), "identity", CTRL+Key_N, this,
+ action = new TDEAction( i18n( "&New Contact..." ), "identity", CTRL+Key_N, this,
TQT_SLOT( newContact() ), actionCollection(), "file_new_contact" );
action->setWhatsThis( i18n( "Create a new contact<p>You will be presented with a dialog where you can add all data about a person, including addresses and phone numbers." ) );
- action = new KAction( i18n( "&New Distribution List..." ), "kontact_contacts", 0, this,
+ action = new TDEAction( i18n( "&New Distribution List..." ), "kontact_contacts", 0, this,
TQT_SLOT( newDistributionList() ), actionCollection(), "file_new_distributionlist" );
action->setWhatsThis( i18n( "Create a new distribution list<p>You will be presented with a dialog where you can create a new distribution list." ) );
- mActionMailVCard = new KAction( i18n("Send &Contact..."), "mail_post_to", 0,
+ mActionMailVCard = new TDEAction( i18n("Send &Contact..."), "mail_post_to", 0,
this, TQT_SLOT( mailVCard() ),
actionCollection(), "file_mail_vcard" );
mActionMailVCard->setWhatsThis( i18n( "Send a mail with the selected contact as attachment." ) );
- mActionChat = new KAction( i18n("Chat &With..."), 0,
+ mActionChat = new TDEAction( i18n("Chat &With..."), 0,
this, TQT_SLOT( startChat() ),
actionCollection(), "file_chat" );
mActionChat->setWhatsThis( i18n( "Start a chat with the selected contact." ) );
- mActionEditAddressee = new KAction( i18n( "&Edit Contact..." ), "edit", 0,
+ mActionEditAddressee = new TDEAction( i18n( "&Edit Contact..." ), "edit", 0,
this, TQT_SLOT( editContact() ),
actionCollection(), "file_properties" );
mActionEditAddressee->setWhatsThis( i18n( "Edit a contact<p>You will be presented with a dialog where you can change all data about a person, including addresses and phone numbers." ) );
- mActionMerge = new KAction( i18n( "&Merge Contacts" ), "", 0,
+ mActionMerge = new TDEAction( i18n( "&Merge Contacts" ), "", 0,
this, TQT_SLOT( mergeContacts() ),
actionCollection(), "edit_merge" );
@@ -1366,38 +1366,38 @@ void KABCore::initActions()
// mActionUndo->setWhatsThis( i18n( "Undoes the last <b>Cut</b>, <b>Copy</b> or <b>Paste</b>." ) );
// mActionRedo->setWhatsThis( i18n( "Redoes the last <b>Cut</b>, <b>Copy</b> or <b>Paste</b>." ) );
- mActionDelete = new KAction( i18n( "&Delete Contact" ), "editdelete",
+ mActionDelete = new TDEAction( i18n( "&Delete Contact" ), "editdelete",
Key_Delete, this, TQT_SLOT( deleteContacts() ),
actionCollection(), "edit_delete" );
mActionDelete->setWhatsThis( i18n( "Delete all selected contacts." ) );
- mActionCopyAddresseeTo = new KAction( i18n( "&Copy Contact To..." ), "", 0,
+ mActionCopyAddresseeTo = new TDEAction( i18n( "&Copy Contact To..." ), "", 0,
this, TQT_SLOT( copySelectedContactToResource() ),
actionCollection(), "copy_contact_to" );
const TQString copyMoveWhatsThis = i18n( "Store a contact in a different Addressbook<p>You will be presented with a dialog where you can select a new storage place for this contact." );
mActionCopyAddresseeTo->setWhatsThis( copyMoveWhatsThis );
- mActionMoveAddresseeTo = new KAction( i18n( "M&ove Contact To..." ), "", 0,
+ mActionMoveAddresseeTo = new TDEAction( i18n( "M&ove Contact To..." ), "", 0,
this, TQT_SLOT( moveSelectedContactToResource() ),
actionCollection(), "move_contact_to" );
mActionMoveAddresseeTo->setWhatsThis( copyMoveWhatsThis );
// settings menu
- mActionJumpBar = new KToggleAction( i18n( "Show Jump Bar" ), "next", 0,
+ mActionJumpBar = new TDEToggleAction( i18n( "Show Jump Bar" ), "next", 0,
actionCollection(), "options_show_jump_bar" );
mActionJumpBar->setWhatsThis( i18n( "Toggle whether the jump button bar shall be visible." ) );
mActionJumpBar->setCheckedState( i18n( "Hide Jump Bar") );
connect( mActionJumpBar, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( setJumpButtonBarVisible( bool ) ) );
- mActionDetails = new KToggleAction( i18n( "Show Details" ), 0, 0,
+ mActionDetails = new TDEToggleAction( i18n( "Show Details" ), 0, 0,
actionCollection(), "options_show_details" );
mActionDetails->setWhatsThis( i18n( "Toggle whether the details page shall be visible." ) );
mActionDetails->setCheckedState( i18n( "Hide Details") );
connect( mActionDetails, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( setDetailsVisible( bool ) ) );
if ( mIsPart )
- action = new KAction( i18n( "&Configure Address Book..." ), "configure", 0,
+ action = new TDEAction( i18n( "&Configure Address Book..." ), "configure", 0,
this, TQT_SLOT( configure() ), actionCollection(),
"kaddressbook_configure" );
else
@@ -1406,21 +1406,21 @@ void KABCore::initActions()
action->setWhatsThis( i18n( "You will be presented with a dialog, that offers you all possibilities to configure KAddressBook." ) );
// misc
- action = new KAction( i18n( "&Lookup Addresses in LDAP Directory..." ), "find", 0,
+ action = new TDEAction( i18n( "&Lookup Addresses in LDAP Directory..." ), "find", 0,
this, TQT_SLOT( openLDAPDialog() ), actionCollection(), "ldap_lookup" );
action->setWhatsThis( i18n( "Search for contacts on a LDAP server<p>You will be presented with a dialog, where you can search for contacts and select the ones you want to add to your local address book." ) );
- mActionWhoAmI = new KAction( i18n( "Set as Personal Contact Data" ), "personal", 0, this,
+ mActionWhoAmI = new TDEAction( i18n( "Set as Personal Contact Data" ), "personal", 0, this,
TQT_SLOT( setWhoAmI() ), actionCollection(),
"edit_set_personal" );
mActionWhoAmI->setWhatsThis( i18n( "Set the personal contact<p>The data of this contact will be used in many other TDE applications, so you do not have to input your personal data several times." ) );
- mActionCategories = new KAction( i18n( "Select Categories..." ), 0, this,
+ mActionCategories = new TDEAction( i18n( "Select Categories..." ), 0, this,
TQT_SLOT( setCategories() ), actionCollection(),
"edit_set_categories" );
mActionCategories->setWhatsThis( i18n( "Set the categories for all selected contacts." ) );
- KAction *clearLocation = new KAction( i18n( "Clear Search Bar" ),
+ TDEAction *clearLocation = new TDEAction( i18n( "Clear Search Bar" ),
TQApplication::reverseLayout() ? "clear_left" : "locationbar_erase",
CTRL+Key_L, this, TQT_SLOT( slotClearSearchBar() ), actionCollection(), "clear_search" );
clearLocation->setWhatsThis( i18n( "Clear Search Bar<p>"
diff --git a/kaddressbook/kabcore.h b/kaddressbook/kabcore.h
index c8d36872..a18692fa 100644
--- a/kaddressbook/kabcore.h
+++ b/kaddressbook/kabcore.h
@@ -47,12 +47,12 @@ class CategorySelectDialog;
}
class TDEAboutData;
-class KAction;
-class KActionCollection;
+class TDEAction;
+class TDEActionCollection;
class TDEConfig;
class KPushButton;
class KStatusBar;
-class KToggleAction;
+class TDEToggleAction;
class KXMLGUIClient;
class TQSplitter;
@@ -111,10 +111,10 @@ class KDE_EXPORT KABCore : public KAB::Core
TDEConfig *config() const;
/**
- Returns a pointer to the global KActionCollection object. So
+ Returns a pointer to the global TDEActionCollection object. So
other classes can register their actions easily.
*/
- KActionCollection *actionCollection() const;
+ TDEActionCollection *actionCollection() const;
/**
Returns the current sort field of the view.
@@ -477,23 +477,23 @@ class KDE_EXPORT KABCore : public KAB::Core
TQTimer *mAddressBookChangedTimer;
- KAction *mActionPaste;
- KAction *mActionCut;
- KAction *mActionDelete;
- KAction *mActionCopy;
- KAction *mActionEditAddressee;
- KAction *mActionMoveAddresseeTo;
- KAction *mActionCopyAddresseeTo;
- KAction *mActionMerge;
- KAction *mActionMail;
- KAction *mActionMailVCard;
- KAction *mActionChat;
- KAction *mActionSave;
- KAction *mActionDeleteView;
- KAction *mActionWhoAmI;
- KAction *mActionCategories;
- KToggleAction *mActionJumpBar;
- KToggleAction *mActionDetails;
+ TDEAction *mActionPaste;
+ TDEAction *mActionCut;
+ TDEAction *mActionDelete;
+ TDEAction *mActionCopy;
+ TDEAction *mActionEditAddressee;
+ TDEAction *mActionMoveAddresseeTo;
+ TDEAction *mActionCopyAddresseeTo;
+ TDEAction *mActionMerge;
+ TDEAction *mActionMail;
+ TDEAction *mActionMailVCard;
+ TDEAction *mActionChat;
+ TDEAction *mActionSave;
+ TDEAction *mActionDeleteView;
+ TDEAction *mActionWhoAmI;
+ TDEAction *mActionCategories;
+ TDEToggleAction *mActionJumpBar;
+ TDEToggleAction *mActionDetails;
KCommandHistory *mCommandHistory;
KAddressBookService *mAddressBookService;
diff --git a/kaddressbook/kaddressbookmain.cpp b/kaddressbook/kaddressbookmain.cpp
index 9c2d476e..4e5cf8ff 100644
--- a/kaddressbook/kaddressbookmain.cpp
+++ b/kaddressbook/kaddressbookmain.cpp
@@ -35,7 +35,7 @@
#include "kaddressbookmain.h"
KAddressBookMain::KAddressBookMain( const TQString &file )
- : DCOPObject( "KAddressBookIface" ), KMainWindow( 0 )
+ : DCOPObject( "KAddressBookIface" ), TDEMainWindow( 0 )
{
// Set this to be the group leader for all subdialogs - this means
// modal subdialogs will only affect this dialog, not the other windows
@@ -152,7 +152,7 @@ void KAddressBookMain::initActions()
{
KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection() );
- KAction *action;
+ TDEAction *action;
action = KStdAction::keyBindings( TQT_TQOBJECT(this), TQT_SLOT( configureKeyBindings() ), actionCollection() );
action->setWhatsThis( i18n( "You will be presented with a dialog, where you can configure the application wide shortcuts." ) );
diff --git a/kaddressbook/kaddressbookmain.h b/kaddressbook/kaddressbookmain.h
index 3e8ffb83..a8ac77e2 100644
--- a/kaddressbook/kaddressbookmain.h
+++ b/kaddressbook/kaddressbookmain.h
@@ -42,7 +42,7 @@ class KABCore;
@author Don Sanders <dsanders@kde.org>
@version 0.1
*/
-class KAddressBookMain : public KMainWindow, virtual public KAddressBookIface
+class KAddressBookMain : public TDEMainWindow, virtual public KAddressBookIface
{
Q_OBJECT
diff --git a/kaddressbook/kaddressbookview.h b/kaddressbook/kaddressbookview.h
index 1f26ca71..d6ba8d6a 100644
--- a/kaddressbook/kaddressbookview.h
+++ b/kaddressbook/kaddressbookview.h
@@ -202,7 +202,7 @@ class KDE_EXPORT KAddressBookView : public TQWidget
@param uid The uid of the selected addressee.
- @see KListView
+ @see TDEListView
*/
void selected( const TQString &uid );
@@ -213,7 +213,7 @@ class KDE_EXPORT KAddressBookView : public TQWidget
@param uid The uid of the selected addressee
- @see KListView
+ @see TDEListView
*/
void executed( const TQString &uid );
diff --git a/kaddressbook/kcmconfigs/addhostdialog.cpp b/kaddressbook/kcmconfigs/addhostdialog.cpp
index 53c06e2a..21a24780 100644
--- a/kaddressbook/kcmconfigs/addhostdialog.cpp
+++ b/kaddressbook/kcmconfigs/addhostdialog.cpp
@@ -90,7 +90,7 @@ AddHostDialog::AddHostDialog( KPIM::LdapServer *server, TQWidget* parent, const
}
mCfg->setMech( mServer->mech() );
- KAcceleratorManager::manage( this );
+ TDEAcceleratorManager::manage( this );
}
diff --git a/kaddressbook/kcmconfigs/kabconfigwidget.h b/kaddressbook/kcmconfigs/kabconfigwidget.h
index a3756320..5ee3c789 100644
--- a/kaddressbook/kcmconfigs/kabconfigwidget.h
+++ b/kaddressbook/kcmconfigs/kabconfigwidget.h
@@ -32,7 +32,7 @@ class TQListViewItem;
class TQPushButton;
class TQComboBox;
-class KListView;
+class TDEListView;
class AddresseeWidget;
diff --git a/kaddressbook/kcmconfigs/ldapoptionswidget.cpp b/kaddressbook/kcmconfigs/ldapoptionswidget.cpp
index 12ff1104..981b33cc 100644
--- a/kaddressbook/kcmconfigs/ldapoptionswidget.cpp
+++ b/kaddressbook/kcmconfigs/ldapoptionswidget.cpp
@@ -270,7 +270,7 @@ void LDAPOptionsWidget::initGUI()
TQHBox* hBox = new TQHBox( groupBox );
hBox->setSpacing( 6 );
// Contents of the hbox: listview and up/down buttons on the right (vbox)
- mHostListView = new KListView( hBox );
+ mHostListView = new TDEListView( hBox );
TQVBox* upDownBox = new TQVBox( hBox );
upDownBox->setSpacing( 6 );
diff --git a/kaddressbook/kcmconfigs/ldapoptionswidget.h b/kaddressbook/kcmconfigs/ldapoptionswidget.h
index 8be3b83a..5471b0b6 100644
--- a/kaddressbook/kcmconfigs/ldapoptionswidget.h
+++ b/kaddressbook/kcmconfigs/ldapoptionswidget.h
@@ -27,7 +27,7 @@
#include <tqwidget.h>
class TQToolButton;
-class KListView;
+class TDEListView;
class TQListViewItem;
class TQPushButton;
@@ -59,7 +59,7 @@ class LDAPOptionsWidget : public TQWidget
private:
void initGUI();
- KListView* mHostListView;
+ TDEListView* mHostListView;
TQPushButton* mAddButton;
TQPushButton* mEditButton;
diff --git a/kaddressbook/main.cpp b/kaddressbook/main.cpp
index fa2d03bf..fd5a3149 100644
--- a/kaddressbook/main.cpp
+++ b/kaddressbook/main.cpp
@@ -56,7 +56,7 @@ int KAddressBookApp::newInstance()
{
if ( isRestored() ) {
// There can only be one main window
- if ( KMainWindow::canBeRestored( 1 ) ) {
+ if ( TDEMainWindow::canBeRestored( 1 ) ) {
mMainWin = new KAddressBookMain;
setMainWidget( mMainWin );
mMainWin->show();
@@ -124,7 +124,7 @@ int main( int argc, char *argv[] )
TDEGlobal::locale()->insertCatalogue( "libtdepim" );
bool ret = app.exec();
- while (KMainWindow::memberList->first())
- delete KMainWindow::memberList->first();
+ while (TDEMainWindow::memberList->first())
+ delete TDEMainWindow::memberList->first();
return ret;
}
diff --git a/kaddressbook/nameeditdialog.cpp b/kaddressbook/nameeditdialog.cpp
index 1bba99ff..aa76fdef 100644
--- a/kaddressbook/nameeditdialog.cpp
+++ b/kaddressbook/nameeditdialog.cpp
@@ -157,7 +157,7 @@ NameEditDialog::NameEditDialog( const KABC::Addressee &addr, int type,
mAddresseeConfig.setAddressee( addr );
mParseBox->setChecked( mAddresseeConfig.automaticNameParsing() );
- KAcceleratorManager::manage( this );
+ TDEAcceleratorManager::manage( this );
connect( mPrefixCombo, TQT_SIGNAL( textChanged( const TQString& ) ),
this, TQT_SLOT( modified() ) );
diff --git a/kaddressbook/printing/ds_appearance.ui b/kaddressbook/printing/ds_appearance.ui
index 9dc64b9e..d33bc86a 100644
--- a/kaddressbook/printing/ds_appearance.ui
+++ b/kaddressbook/printing/ds_appearance.ui
@@ -207,7 +207,7 @@
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
- <widget class="KFontCombo" row="2" column="1">
+ <widget class="TDEFontCombo" row="2" column="1">
<property name="name">
<cstring>kfcBodyFont</cstring>
</property>
@@ -220,7 +220,7 @@
</sizepolicy>
</property>
</widget>
- <widget class="KFontCombo" row="3" column="1">
+ <widget class="TDEFontCombo" row="3" column="1">
<property name="name">
<cstring>kfcDetailsFont</cstring>
</property>
@@ -233,7 +233,7 @@
</sizepolicy>
</property>
</widget>
- <widget class="KFontCombo" row="4" column="1">
+ <widget class="TDEFontCombo" row="4" column="1">
<property name="name">
<cstring>kfcFixedFont</cstring>
</property>
@@ -249,7 +249,7 @@
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
- <widget class="KFontCombo" row="0" column="1">
+ <widget class="TDEFontCombo" row="0" column="1">
<property name="name">
<cstring>kfcHeaderFont</cstring>
</property>
@@ -262,7 +262,7 @@
</sizepolicy>
</property>
</widget>
- <widget class="KFontCombo" row="1" column="1">
+ <widget class="TDEFontCombo" row="1" column="1">
<property name="name">
<cstring>kfcHeadlineFont</cstring>
</property>
diff --git a/kaddressbook/viewmanager.cpp b/kaddressbook/viewmanager.cpp
index 937f994c..4ac23786 100644
--- a/kaddressbook/viewmanager.cpp
+++ b/kaddressbook/viewmanager.cpp
@@ -564,36 +564,36 @@ int ViewManager::filterPosition( const TQString &name ) const
void ViewManager::initActions()
{
- mActionSelectView = new KSelectAction( i18n( "Select View" ), 0, mCore->actionCollection(), "select_view" );
+ mActionSelectView = new TDESelectAction( i18n( "Select View" ), 0, mCore->actionCollection(), "select_view" );
#if TDE_VERSION >= 309
mActionSelectView->setMenuAccelsEnabled( false );
#endif
connect( mActionSelectView, TQT_SIGNAL( activated( const TQString& ) ),
TQT_SLOT( setActiveView( const TQString& ) ) );
- KAction *action;
+ TDEAction *action;
- action = new KAction( i18n( "Modify View..." ), "configure", 0, TQT_TQOBJECT(this),
+ action = new TDEAction( i18n( "Modify View..." ), "configure", 0, TQT_TQOBJECT(this),
TQT_SLOT( editView() ), mCore->actionCollection(),
"view_modify" );
action->setWhatsThis( i18n( "By pressing this button a dialog opens that allows you to modify the view of the addressbook. There you can add or remove fields that you want to be shown or hidden in the addressbook like the name for example." ) );
- action = new KAction( i18n( "Add View..." ), "window_new", 0, TQT_TQOBJECT(this),
+ action = new TDEAction( i18n( "Add View..." ), "window_new", 0, TQT_TQOBJECT(this),
TQT_SLOT( addView() ), mCore->actionCollection(),
"view_add" );
action->setWhatsThis( i18n( "You can add a new view by choosing one from the dialog that appears after pressing the button. You have to give the view a name, so that you can distinguish between the different views." ) );
- mActionDeleteView = new KAction( i18n( "Delete View" ), "view_remove", 0,
+ mActionDeleteView = new TDEAction( i18n( "Delete View" ), "view_remove", 0,
TQT_TQOBJECT(this), TQT_SLOT( deleteView() ),
mCore->actionCollection(), "view_delete" );
mActionDeleteView->setWhatsThis( i18n( "By pressing this button you can delete the actual view, which you have added before." ) );
- action = new KAction( i18n( "Refresh View" ), "reload", 0, TQT_TQOBJECT(this),
+ action = new TDEAction( i18n( "Refresh View" ), "reload", 0, TQT_TQOBJECT(this),
TQT_SLOT( refreshView() ), mCore->actionCollection(),
"view_refresh" );
action->setWhatsThis( i18n( "The view will be refreshed by pressing this button." ) );
- action = new KAction( i18n( "Edit &Filters..." ), "filter", 0, TQT_TQOBJECT(this),
+ action = new TDEAction( i18n( "Edit &Filters..." ), "filter", 0, TQT_TQOBJECT(this),
TQT_SLOT( configureFilters() ), mCore->actionCollection(),
"options_edit_filters" );
action->setWhatsThis( i18n( "Edit the contact filters<p>You will be presented with a dialog, where you can add, remove and edit filters." ) );
diff --git a/kaddressbook/viewmanager.h b/kaddressbook/viewmanager.h
index 699d1d17..d248a6ba 100644
--- a/kaddressbook/viewmanager.h
+++ b/kaddressbook/viewmanager.h
@@ -31,8 +31,8 @@
class TQDropEvent;
class TQWidgetStack;
-class KAction;
-class KSelectAction;
+class TDEAction;
+class TDESelectAction;
class FilterSelectionWidget;
@@ -154,8 +154,8 @@ class ViewManager : public TQWidget
TQWidgetStack *mViewWidgetStack;
KAddressBookView *mActiveView;
- KAction *mActionDeleteView;
- KSelectAction *mActionSelectView;
+ TDEAction *mActionDeleteView;
+ TDESelectAction *mActionSelectView;
FilterSelectionWidget *mFilterSelectionWidget;
};
diff --git a/kaddressbook/views/colorlistbox.cpp b/kaddressbook/views/colorlistbox.cpp
index a003246f..54ad38b3 100644
--- a/kaddressbook/views/colorlistbox.cpp
+++ b/kaddressbook/views/colorlistbox.cpp
@@ -26,7 +26,7 @@
#include "colorlistbox.h"
ColorListBox::ColorListBox( TQWidget *parent, const char *name, WFlags f )
- :KListBox( parent, name, f ), mCurrentOnDragEnter(-1)
+ :TDEListBox( parent, name, f ), mCurrentOnDragEnter(-1)
{
connect( this, TQT_SIGNAL(selected(int)), this, TQT_SLOT(newColor(int)) );
setAcceptDrops( true);
diff --git a/kaddressbook/views/colorlistbox.h b/kaddressbook/views/colorlistbox.h
index 63495e93..18c307ac 100644
--- a/kaddressbook/views/colorlistbox.h
+++ b/kaddressbook/views/colorlistbox.h
@@ -23,7 +23,7 @@
#include <klistbox.h>
-class ColorListBox : public KListBox
+class ColorListBox : public TDEListBox
{
Q_OBJECT
diff --git a/kaddressbook/views/configurecardviewdialog.cpp b/kaddressbook/views/configurecardviewdialog.cpp
index b1e6233e..4cfbf958 100644
--- a/kaddressbook/views/configurecardviewdialog.cpp
+++ b/kaddressbook/views/configurecardviewdialog.cpp
@@ -167,14 +167,14 @@ void CardViewLookNFeelPage::saveSettings( TDEConfig *config )
void CardViewLookNFeelPage::setTextFont()
{
TQFont f( lTextFont->font() );
- if ( KFontDialog::getFont( f, false, this ) == TQDialog::Accepted )
+ if ( TDEFontDialog::getFont( f, false, this ) == TQDialog::Accepted )
updateFontLabel( f, lTextFont );
}
void CardViewLookNFeelPage::setHeaderFont()
{
TQFont f( lHeaderFont->font() );
- if ( KFontDialog::getFont( f,false, this ) == TQDialog::Accepted )
+ if ( TDEFontDialog::getFont( f,false, this ) == TQDialog::Accepted )
updateFontLabel( f, lHeaderFont );
}
diff --git a/kaddressbook/views/contactlistview.cpp b/kaddressbook/views/contactlistview.cpp
index 25c66ac4..a0aec1e9 100644
--- a/kaddressbook/views/contactlistview.cpp
+++ b/kaddressbook/views/contactlistview.cpp
@@ -151,7 +151,7 @@ ContactListViewItem::ContactListViewItem(const KABC::Addressee &a,
KABC::AddressBook *doc,
const KABC::Field::List &fields,
KIMProxy *proxy )
- : KListViewItem(parent), mAddressee(a), mFields( fields ),
+ : TDEListViewItem(parent), mAddressee(a), mFields( fields ),
parentListView( parent ), mDocument(doc), mIMProxy( proxy )
{
if ( mIMProxy )
@@ -196,7 +196,7 @@ void ContactListViewItem::paintCell(TQPainter * p,
int width,
int align)
{
- KListViewItem::paintCell(p, cg, column, width, align);
+ TDEListViewItem::paintCell(p, cg, column, width, align);
if ( !p )
return;
@@ -260,7 +260,7 @@ ContactListView::ContactListView(KAddressBookTableView *view,
KABC::AddressBook* /* doc */,
TQWidget *parent,
const char *name )
- : KListView( parent, name ),
+ : TDEListView( parent, name ),
pabWidget( view ),
oldColumn( 0 )
{
@@ -275,7 +275,7 @@ ContactListView::ContactListView(KAddressBookTableView *view,
viewport()->setAcceptDrops( true );
setAllColumnsShowFocus( true );
setShowSortIndicator(true);
- setSelectionModeExt( KListView::Extended );
+ setSelectionModeExt( TDEListView::Extended );
setDropVisualizer(false);
connect(this, TQT_SIGNAL(dropped(TQDropEvent*)),
@@ -300,14 +300,14 @@ void ContactListView::paintEmptyArea( TQPainter * p, const TQRect & rect )
else
{
// Do a normal paint
- KListView::paintEmptyArea(p, rect);
+ TDEListView::paintEmptyArea(p, rect);
}
}
void ContactListView::contentsMousePressEvent(TQMouseEvent* e)
{
presspos = e->pos();
- KListView::contentsMousePressEvent(e);
+ TDEListView::contentsMousePressEvent(e);
}
@@ -318,7 +318,7 @@ void ContactListView::contentsMouseMoveEvent( TQMouseEvent *e )
emit startAddresseeDrag();
}
else
- KListView::contentsMouseMoveEvent( e );
+ TDEListView::contentsMouseMoveEvent( e );
}
bool ContactListView::acceptDrag(TQDropEvent *e) const
diff --git a/kaddressbook/views/contactlistview.h b/kaddressbook/views/contactlistview.h
index 2da52d23..adfbc2dc 100644
--- a/kaddressbook/views/contactlistview.h
+++ b/kaddressbook/views/contactlistview.h
@@ -52,7 +52,7 @@ class DynamicTip : public TQToolTip
private:
};
-class ContactListViewItem : public KListViewItem
+class ContactListViewItem : public TDEListViewItem
{
public:
@@ -82,7 +82,7 @@ private:
/////////////////////////////////////////////
// ContactListView
-class ContactListView : public KListView
+class ContactListView : public TDEListView
{
Q_OBJECT
diff --git a/kaddressbook/views/kaddressbooktableview.cpp b/kaddressbook/views/kaddressbooktableview.cpp
index 4c39c13b..f0c4c594 100644
--- a/kaddressbook/views/kaddressbooktableview.cpp
+++ b/kaddressbook/views/kaddressbooktableview.cpp
@@ -147,8 +147,8 @@ void KAddressBookTableView::reconstructListView()
this, TQT_SIGNAL( startDrag() ) );
connect( mListView, TQT_SIGNAL( addresseeDropped( TQDropEvent* ) ),
this, TQT_SIGNAL( dropped( TQDropEvent* ) ) );
- connect( mListView, TQT_SIGNAL( contextMenu( KListView*, TQListViewItem*, const TQPoint& ) ),
- this, TQT_SLOT( rmbClicked( KListView*, TQListViewItem*, const TQPoint& ) ) );
+ connect( mListView, TQT_SIGNAL( contextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ),
+ this, TQT_SLOT( rmbClicked( TDEListView*, TQListViewItem*, const TQPoint& ) ) );
connect( mListView->header(), TQT_SIGNAL( clicked( int ) ),
this, TQT_SIGNAL( sortFieldChanged() ) );
@@ -347,7 +347,7 @@ void KAddressBookTableView::addresseeExecuted( TQListViewItem *item )
}
}
-void KAddressBookTableView::rmbClicked( KListView*, TQListViewItem*, const TQPoint &point )
+void KAddressBookTableView::rmbClicked( TDEListView*, TQListViewItem*, const TQPoint &point )
{
popup( point );
}
diff --git a/kaddressbook/views/kaddressbooktableview.h b/kaddressbook/views/kaddressbooktableview.h
index 4ebdfd93..acbfb08d 100644
--- a/kaddressbook/views/kaddressbooktableview.h
+++ b/kaddressbook/views/kaddressbooktableview.h
@@ -50,7 +50,7 @@ class ContactListView;
namespace KABC { class AddressBook; }
/**
* This class is the table view for kaddressbook. This view is a KListView
* with multiple columns for the selected fields.
*
* @short Table View
@@ -100,7 +100,7 @@ friend class ContactListView;
/**
RBM menu called.
*/
- void rmbClicked( KListView*, TQListViewItem*, const TQPoint& );
+ void rmbClicked( TDEListView*, TQListViewItem*, const TQPoint& );
/**
* Called to update the presence of a single item
@@ -50,7 +50,7 @@ class ContactListView;
namespace KABC { class AddressBook; }
/**
- * This class is the table view for kaddressbook. This view is a KListView
+ * This class is the table view for kaddressbook. This view is a TDEListView
* with multiple columns for the selected fields.
*